@@ -141,10 +141,10 @@ class DWARFTreeModel(QAbstractItemModel):
                 self.createIndex(0, 0, self.top_dies[0]),
                 self.createIndex(len(self.top_dies)-1, 0, self.top_dies[-1]))    
 
-    # returns the model index of the selection
+    # returns the model index of the selection, or None
     def set_sortcus(self, sortcus, sel):
         if sortcus != self.sortcus:
-            sel_die = sel.internalPointer()
+            sel_die = sel.internalPointer() if sel.isValid() else None
             self.beginResetModel()
             self.sortcus = sortcus
             #Resort the CUs, reload the top_dies
@@ -157,11 +157,13 @@ class DWARFTreeModel(QAbstractItemModel):
                 self.top_dies[i]._i = i
             # Reload
             self.endResetModel()
-            if sel_die.get_parent(): # Not a top level
-                return sel
-            else:
-                return self.createIndex(0, sel_die._i, sel_die)
+            if sel_die:
+                if sel_die.get_parent(): # Not a top level
+                    return sel
+                else:
+                    return self.createIndex(0, sel_die._i, sel_die)
 
+    # Returns the index of the new selection, if any
     def set_sortdies(self, sortdies):
         if sortdies != self.sortdies:
             self.sortdies = sortdies
@@ -187,9 +189,10 @@ class DWARFTreeModel(QAbstractItemModel):
     def index_for_navitem(self, navitem):
         target_cu, target_offset = navitem
         # Random access is a tricky proposition in the current version. Parse the whole CU.
-        for die in target_cu.iter_DIEs():
+        for _ in target_cu.iter_DIEs():
             pass
 
+        # Abusing the structure of the per-CU DIE cache of pyelftools, it's the same in DWWARFv1
         i = bisect_left(target_cu._diemap, target_offset)
         target_die = target_cu._dielist[i]
         return self.index_for_die(target_die)
@@ -233,7 +236,7 @@ class DWARFTreeModel(QAbstractItemModel):
             if cu_cond(cu) if cu_cond else True:
                 for die in cu.iter_DIEs():
                     # Quit condition with search from position - quit once we go past the starting position after the wrap
-                    if cu_offset >= start_cu_offset and die.offset > start_die_offset and wrapped:
+                    if have_start_pos and cu_offset >= start_cu_offset and die.offset > start_die_offset and wrapped:
                         break
                     if (not have_start_pos or cu_offset != start_cu_offset or (not wrapped and die.offset > start_die_offset)) and cond(die):
                         return self.index_for_die(die)
